/*
 * Plot - plot time-based data on screen and to file with interactive controls
 * Copyright (C) 2006  Jonas Berlin <xkr47@outerspace.dyndns.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 ****
 * main - main function setting up some gtk stuff and loading data
 * files given on command line
 */

#include <gtk/gtkmain.h>
#include <glade/glade-xml.h>

#include "plot2.xh"

gboolean destroy_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);

int quit = 0;

gboolean destroy_event(GtkWidget *widget, GdkEvent *event, gpointer user_data) {
   if(gtk_main_level()) gtk_main_quit();
   quit = 1;
   return 1;
}

int main(int arg_count, char **arg) {
   gtk_init(&arg_count, &arg);

   const char *gladefile = "plot.glade";

   GladeXML *gladexml = glade_xml_new(gladefile, "window1", NULL);
   //glade_xml_signal_autoconnect(gladexml);

   GtkWidget *win = glade_xml_get_widget(gladexml, "window1");

   g_signal_connect(win, "destroy-event", G_CALLBACK(destroy_event), (gpointer)0);
   g_signal_connect(win, "delete-event", G_CALLBACK(destroy_event), (gpointer)1);

   my_plot_t plot;
   plot_init(&plot);

   plot.parent = GTK_WINDOW(win);
   plot.da = glade_xml_get_widget(gladexml, "drawingarea1");
   plot.show_disabled = 1;
   plot.font = g_strdup("Verdana 18");
   plot.fontsize_at_width = 1600;
   plot.scale_font_by_size = 1;

   plot.button_zoom_prev = glade_xml_get_widget(gladexml, "button_zoom_prev");
   plot.button_zoom_next = glade_xml_get_widget(gladexml, "button_zoom_next");
   gtk_widget_set_sensitive(plot.button_zoom_prev, 0);
   gtk_widget_set_sensitive(plot.button_zoom_next, 0);

   plot.minor_color = "#606060";
   plot.major_color = "#c0c0c0";
   plot.sep_color = "#808080";
   plot.label_color = "#ffffff";
   plot.cursor_marker_color = "#808080";
   plot.legend_bg_color = "#202020";
   plot.legend_border_color = "#a0a0a0";
   plot.legend_text_color = "#e0e0e0";

   /*
     gchar bits[] = { 0 };
     GdkColor color = { 0, 0, 0, 0 };
     GdkCursor *cursor;

     GdkPixmap *pixmap = gdk_bitmap_create_from_data(NULL, bits, 1, 1);
     GdkCursor *cursor = gdk_cursor_new_from_pixmap(pixmap, pixmap, &color, &color, 0, 0);
     gdk_window_set_cursor(GDK_WINDOW(window), cursor);
   */

   plot_connect_signals(&plot, gladefile, gladexml);

   GdkCursor *cursor = gdk_cursor_new(GDK_DRAFT_SMALL);
   gdk_window_set_cursor(plot.da->window, cursor);
   gdk_cursor_unref(cursor);

   plot.dsc_x = data_scrollbar_controller_new(gladexml, "xscroll_");
   plot.dsc_y = data_scrollbar_controller_new(gladexml, "yscroll_");

   plot.progressbar = GTK_PROGRESS_BAR(glade_xml_get_widget(gladexml, "progressbar"));
   plot.menuitem_file_add_data_file = glade_xml_get_widget(gladexml, "menuitem_file_add_data_file");

   while(gtk_events_pending()) gtk_main_iteration();

   for(int a=1; a<arg_count; ++a) {
      add_datafile(&plot, arg[a]);
   }

   // set initial center
   double min, max;
   data_scrollbar_controller_get_range(plot.dsc_y, &min, &max);
   data_scrollbar_controller_set_zoompoint(plot.dsc_y, min > 0 ? 0 : max < 0 ? 1 : -min / (max - min)); // align to(wards) zero
   data_scrollbar_controller_set_zoompoint(plot.dsc_x, 1.0); // align to right

   if(!quit) gtk_main();

   return 0;
}
